@@ -123,7 +123,8 @@ for app in get_apps():
 
             test_name = u'{0}_{1}'.format(
                 app.__package__.replace('.', '_'),
-                os.path.basename(smok_dir).upper().encode('utf-8')
+                os.path.basename(smok_dir)
+            ).upper().encode('utf-8')
             
             attrs = {
                 'fixtures': [],
